==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-commons/nifi-utils/src/main/java/org/apache/nifi/util/concurrency/TimedLock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.util.concurrency;

import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Lock;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class TimedLock {

    private final DebugEnabledTimedLock enabled;
    private final DebugDisabledTimedLock disabled;

    private final Logger logger;

    public TimedLock(final Lock lock, final String name, final int iterationFrequency) {
        this.enabled = new DebugEnabledTimedLock(lock, name, iterationFrequency);
        this.disabled = new DebugDisabledTimedLock(lock);

        logger = LoggerFactory.getLogger(TimedLock.class.getName() + "." + name);
    }

    private DebuggableTimedLock getLock() {
        return logger.isDebugEnabled() ? enabled : disabled;
    }

    public boolean tryLock() {
        return getLock().tryLock();
    }

    public boolean tryLock(final long timeout, final TimeUnit timeUnit) {
        return getLock().tryLock(timeout, timeUnit);
    }

    public void lock() {
        getLock().lock();
    }

    public void unlock(final String task) {
        getLock().unlock(task);
    }

}

==> nifi-2.7.1-source-release.zip: nifi-2.7.1/nifi-commons/nifi-utils/src/main/java/org/apache/nifi/util/concurrency/TimedLock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.util.concurrency;

import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Lock;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class TimedLock {

    private final DebugEnabledTimedLock enabled;
    private final DebugDisabledTimedLock disabled;

    private static final Logger logger = LoggerFactory.getLogger(TimedLock.class.getName());

    public TimedLock(final Lock lock, final String name, final int iterationFrequency) {
        this.enabled = new DebugEnabledTimedLock(lock, name, iterationFrequency);
        this.disabled = new DebugDisabledTimedLock(lock);
    }

    private DebuggableTimedLock getLock() {
        return logger.isDebugEnabled() ? enabled : disabled;
    }

    public boolean tryLock() {
        return getLock().tryLock();
    }

    public boolean tryLock(final long timeout, final TimeUnit timeUnit) {
        return getLock().tryLock(timeout, timeUnit);
    }

    public void lock() {
        getLock().lock();
    }

    public void unlock(final String task) {
        getLock().unlock(task);
    }

}
